fn mod_inv(n: i128, m: i128) -> i128Expand description
Modular multiplicative inverse calculated using the extended Euclidean algorithm.
fn mod_inv(n: i128, m: i128) -> i128Modular multiplicative inverse calculated using the extended Euclidean algorithm.